==> zio-aws-cognitosync_2.12-5.17.155.1-sources.jar: zio/aws/cognitosync/model/SetIdentityPoolConfigurationResponse.scala <==
package zio.aws.cognitosync.model
import zio.aws.cognitosync.model.primitives.IdentityPoolId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class SetIdentityPoolConfigurationResponse(
    identityPoolId: Option[IdentityPoolId] = None,
    pushSync: Option[zio.aws.cognitosync.model.PushSync] = None,
    cognitoStreams: Option[zio.aws.cognitosync.model.CognitoStreams] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitosync.model.SetIdentityPoolConfigurationResponse = {
    import SetIdentityPoolConfigurationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitosync.model.SetIdentityPoolConfigurationResponse
      .builder()
      .optionallyWith(
        identityPoolId.map(value =>
          IdentityPoolId.unwrap(value): java.lang.String
        )
      )(_.identityPoolId)
      .optionallyWith(pushSync.map(value => value.buildAwsValue()))(_.pushSync)
      .optionallyWith(cognitoStreams.map(value => value.buildAwsValue()))(
        _.cognitoStreams
      )
      .build()
  }
  def asReadOnly
      : zio.aws.cognitosync.model.SetIdentityPoolConfigurationResponse.ReadOnly =
    zio.aws.cognitosync.model.SetIdentityPoolConfigurationResponse
      .wrap(buildAwsValue())
}
object SetIdentityPoolConfigurationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitosync.model.SetIdentityPoolConfigurationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cognitosync.model.SetIdentityPoolConfigurationResponse =
      zio.aws.cognitosync.model.SetIdentityPoolConfigurationResponse(
        identityPoolId.map(value => value),
        pushSync.map(value => value.asEditable),
        cognitoStreams.map(value => value.asEditable)
      )
    def identityPoolId: Option[IdentityPoolId]
    def pushSync: Option[zio.aws.cognitosync.model.PushSync.ReadOnly]
    def cognitoStreams
        : Option[zio.aws.cognitosync.model.CognitoStreams.ReadOnly]
    def getIdentityPoolId: ZIO[Any, AwsError, IdentityPoolId] =
      AwsError.unwrapOptionField("identityPoolId", identityPoolId)
    def getPushSync
        : ZIO[Any, AwsError, zio.aws.cognitosync.model.PushSync.ReadOnly] =
      AwsError.unwrapOptionField("pushSync", pushSync)
    def getCognitoStreams: ZIO[
      Any,
      AwsError,
      zio.aws.cognitosync.model.CognitoStreams.ReadOnly
    ] = AwsError.unwrapOptionField("cognitoStreams", cognitoStreams)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitosync.model.SetIdentityPoolConfigurationResponse
  ) extends zio.aws.cognitosync.model.SetIdentityPoolConfigurationResponse.ReadOnly {
    override val identityPoolId: Option[IdentityPoolId] = scala
      .Option(impl.identityPoolId())
      .map(value => zio.aws.cognitosync.model.primitives.IdentityPoolId(value))
    override val pushSync: Option[zio.aws.cognitosync.model.PushSync.ReadOnly] =
      scala
        .Option(impl.pushSync())
        .map(value => zio.aws.cognitosync.model.PushSync.wrap(value))
    override val cognitoStreams
        : Option[zio.aws.cognitosync.model.CognitoStreams.ReadOnly] = scala
      .Option(impl.cognitoStreams())
      .map(value => zio.aws.cognitosync.model.CognitoStreams.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitosync.model.SetIdentityPoolConfigurationResponse
  ): zio.aws.cognitosync.model.SetIdentityPoolConfigurationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-cognitosync_2.12-6.20.83.2-sources.jar: zio/aws/cognitosync/model/SetIdentityPoolConfigurationResponse.scala <==
package zio.aws.cognitosync.model
import zio.aws.cognitosync.model.primitives.IdentityPoolId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class SetIdentityPoolConfigurationResponse(
    identityPoolId: Optional[IdentityPoolId] = Optional.Absent,
    pushSync: Optional[zio.aws.cognitosync.model.PushSync] = Optional.Absent,
    cognitoStreams: Optional[zio.aws.cognitosync.model.CognitoStreams] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitosync.model.SetIdentityPoolConfigurationResponse = {
    import SetIdentityPoolConfigurationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitosync.model.SetIdentityPoolConfigurationResponse
      .builder()
      .optionallyWith(
        identityPoolId.map(value =>
          IdentityPoolId.unwrap(value): java.lang.String
        )
      )(_.identityPoolId)
      .optionallyWith(pushSync.map(value => value.buildAwsValue()))(_.pushSync)
      .optionallyWith(cognitoStreams.map(value => value.buildAwsValue()))(
        _.cognitoStreams
      )
      .build()
  }
  def asReadOnly
      : zio.aws.cognitosync.model.SetIdentityPoolConfigurationResponse.ReadOnly =
    zio.aws.cognitosync.model.SetIdentityPoolConfigurationResponse
      .wrap(buildAwsValue())
}
object SetIdentityPoolConfigurationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitosync.model.SetIdentityPoolConfigurationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cognitosync.model.SetIdentityPoolConfigurationResponse =
      zio.aws.cognitosync.model.SetIdentityPoolConfigurationResponse(
        identityPoolId.map(value => value),
        pushSync.map(value => value.asEditable),
        cognitoStreams.map(value => value.asEditable)
      )
    def identityPoolId: Optional[IdentityPoolId]
    def pushSync: Optional[zio.aws.cognitosync.model.PushSync.ReadOnly]
    def cognitoStreams
        : Optional[zio.aws.cognitosync.model.CognitoStreams.ReadOnly]
    def getIdentityPoolId: ZIO[Any, AwsError, IdentityPoolId] =
      AwsError.unwrapOptionField("identityPoolId", identityPoolId)
    def getPushSync
        : ZIO[Any, AwsError, zio.aws.cognitosync.model.PushSync.ReadOnly] =
      AwsError.unwrapOptionField("pushSync", pushSync)
    def getCognitoStreams: ZIO[
      Any,
      AwsError,
      zio.aws.cognitosync.model.CognitoStreams.ReadOnly
    ] = AwsError.unwrapOptionField("cognitoStreams", cognitoStreams)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitosync.model.SetIdentityPoolConfigurationResponse
  ) extends zio.aws.cognitosync.model.SetIdentityPoolConfigurationResponse.ReadOnly {
    override val identityPoolId: Optional[IdentityPoolId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.identityPoolId())
        .map(value =>
          zio.aws.cognitosync.model.primitives.IdentityPoolId(value)
        )
    override val pushSync
        : Optional[zio.aws.cognitosync.model.PushSync.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.pushSync())
        .map(value => zio.aws.cognitosync.model.PushSync.wrap(value))
    override val cognitoStreams
        : Optional[zio.aws.cognitosync.model.CognitoStreams.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cognitoStreams())
        .map(value => zio.aws.cognitosync.model.CognitoStreams.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitosync.model.SetIdentityPoolConfigurationResponse
  ): zio.aws.cognitosync.model.SetIdentityPoolConfigurationResponse.ReadOnly =
    new Wrapper(impl)
}
